__productname__ = "alot-plugin-checkmail"
__version__ = "0.0.15"
__copyright__ = "Copyright (c) 2021 Torgny Bjers"
__author__ = "Torgny Bjers"
__author_email__ = "torgny@bjers.org"
__description__ = "Command wrapper with feedback for checking mail and other long-running tasks."
__url__ = "https://github.com/tbjers/alot-plugin-checkmail"
__license__ = "Licensed under the MIT license."



# Copyright (C) 2021  Torgny Bjers <torgny@bjers.org>
# This file is released under the GNU GPL, version 3 or a later revision.
# For further details see the COPYING file

import argparse
import logging

from alot.helper import call_cmd_async, split_commandstring
from alot.commands import Command, registerCommand
from alot.settings.const import settings


MODE = 'global'

class CheckMailFailed(RuntimeError):
    pass

@registerCommand(MODE, 'checkmail')
class CheckMailCommand(Command):
    def __init__(self, thread=None, **kwargs):
        try:
            if 'checkmail' not in settings._config:
                raise Exception('Missing configuration [checkmail]')
            self.config = settings._config.get('checkmail')
        except Exception as e:
            if ui:
                ui.notify('Missing configuration [checkmail]', priority='error')
        Command.__init__(self, **kwargs)

    async def apply(self, ui):
        try:
            logging.info('checkmail starting...')
            if ui:
                widget = ui.notify('Checking mail...', priority='normal', timeout=-1, block=False)
            conf = settings._config.get('checkmail')
            cmdlist = split_commandstring(conf['command'])
            out, err, code = await call_cmd_async(cmdlist)
            if ui:
                ui.clear_notify([widget])
                if code == 0 and out.strip():
                    message = ''.join([c for c in out.replace('\n', ' ') if c not in ['\t', '\r', '\n']])
                    ui.notify(message, priority='normal', timeout=3, block=False)
            if code != 0:
                if ui:
                    ui.notify('Failed to check mail.', priority='error')
                raise Exception('syncmail returned with code {}{}'.format(code, ':\n' + err.strip() if err else '.'))
        except Exception as e:
            logging.error(str(e))
            raise CheckMailFailed(str(e))
        logging.info('Fetched mail successfully.')
        logging.info(out)



#!/usr/bin/env python3

from setuptools import setup, find_packages
import alot_checkmail

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name=alot_checkmail.__productname__,
    version=alot_checkmail.__version__,
    author=alot_checkmail.__author__,
    author_email=alot_checkmail.__author_email__,
    description=alot_checkmail.__description__,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=alot_checkmail.__url__,
    project_urls={
        "Bug Tracker": "{0}/issues".format(alot_checkmail.__url__),
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=["alot"],
    packages=find_packages(exclude=['tests*']),
    provides=['alot_checkmail'],
    python_requires=">=3.6",
)
